==> haskell-conduit-extra-1.3.8-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-FikLGOsPA9g9kLrHx0Yzz
key:                  conduit-extra-1.3.8-FikLGOsPA9g9kLrHx0Yzz
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  f699fe75f2eaac3c6aac4eb6770532a9
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-FikLGOsPA9g9kLrHx0Yzz
depends:
    async-2.2.5-AixsNKjzHcy7FRtEbJWQ3O
    attoparsec-0.14.4-BMIhC2LZoSCDLMWwXrs2Kd base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-BGhD0oLI63jJc3bUabzWSG
    directory-1.3.7.1 filepath-1.4.2.2
    network-3.1.4.0-2oXWszMMumb2PoHcWOmjnF
    primitive-0.9.0.0-NpldAD031N143U2WBAQrY process-1.6.18.0
    resourcet-1.2.6-4MLLOrswxN1HrnLnm0g3Xb stm-2.5.1.0
    streaming-commons-0.2.3.0-3MumY8uNspYE0mYxZ6EAgW text-2.0.2
    transformers-0.5.6.2 typed-process-0.2.13.0-2C4aeKtMyYJ5n3nQKAKk0
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.8-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-8pleVQgICEo36BRunaYlKV
key:                  conduit-extra-1.3.8-8pleVQgICEo36BRunaYlKV
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  5c9d8e99e09764c547eb68a0a3f5c48d
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-8pleVQgICEo36BRunaYlKV
depends:
    async-2.2.5-BvmUqqFXljF7pOwPZFjKRc
    attoparsec-0.14.4-62hSVPdjEK0BKtGrIEp0w5 base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-FVLYIXkx9NyFPBDwnE2wvC
    directory-1.3.7.1 filepath-1.4.2.2
    network-3.1.4.0-EpGtkoqQTWdJPJAj8Thqiz
    primitive-0.9.0.0-Ldr1crf6mT98Jp7aevHFeM process-1.6.18.0
    resourcet-1.2.6-60kBeMKLYLU7DGwHkUvFW1 stm-2.5.1.0
    streaming-commons-0.2.3.0-34wBwxBZPl06oHoRiEv8KR text-2.0.2
    transformers-0.5.6.2 typed-process-0.2.13.0-9vKLlg0lgdmAkJr2qksv7f
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
